#!/bin/sh
#
# Executes SFPD command on the HSC system
#
# Begin Copyright
#
# IBM Confidential
# The Source code for this program is not published or otherwise divested of its
# trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
# (C) Copyright IBM Corp. 2006
#
# End Copyright

. /usr/svcagent/bin/saFunctions
javaEnvSetup

export PATH=$PATH:/opt/hsc/bin:/usr/sbin

# initialize variables
hsc_vpd=off
vpd_list=off
nodename=
type=
model=
serialno=
microcode=off

# parse command options
set -- `getopt hln:t:m:s:c "$@"`
[ $# -lt 1 ] && exit 1  # getopt failed

# go through all command arguments
while [ $# -gt 0 ] ; do
  case "$1" in
    -h)     hsc_vpd=on;;
    -l)     vpd_list=on;;
    -n)     nodename="$2"; shift;;
    -t)     type="$2"; shift;;
    -m)     model="$2"; shift;;
    -s)     serialno="$2"; shift;;
    -c)     microcode=on; shift;;
    --)     shift; break;;
    -*)
      echo >&2 \
      "wrong argument detected! usage: $0 -h|l -n nodename"
      exit 1;;
      *)      break;;         # terminate while loop
  esac
  shift
done

# execute selected command
#if [[ ${nodename:-""} != "" ]] ; then
   if [[ $hsc_vpd == on ]] ; then
     #lshsc -i -v
     exit 0;
   elif [[ $vpd_list == on ]] ; then
     lshsc -i -t0
     exit 0;
   elif [[ ${type:-""} != "" ]] ; then
     if [[ $microcode == on ]] ; then
       invscout -m "\""$type-$model"\"" -s "\""$serialno"\""
       if [[ $? -eq 0 ]] ; then
           VPDFILE=/var/adm/invscout/$type-$model_$serialno.mup 
           [ -f  $VPDFILE ] && cat $VPDFILE
         fi
     else
       invscout -v -m "\""$type-$model"\"" -s "\""$serialno"\""
       if [[ $? -eq 0 ]] ; then
           VPDFILE=/var/adm/invscout/$type-$model_$serialno.vup 
           [ -f  $VPDFILE ] && cat $VPDFILE
         fi
     fi
     exit 0;
   fi
#fi

# show help information
echo ""
echo "usage: $0 [-h|l] [-t type -m model -s serial_number] [-n nodename]"
echo ""
echo "   -h        return the VPD of the HSC machine"
echo "   -l        return a list of all machines managed by the HSC machine"
echo "   -t        machine type"
echo "   -m        machine model"
echo "   -s        machine serial number"
echo "   -c        the execution of the invscount is for Microcode"
echo "   -n        assign a nodename (not used at this moment)"
echo ""
echo "examples"
echo ""
echo "   $0 -h                   the VPD of the HSC machine"
echo "   $0 -l                   a list of all nodes in format MT-M*SN; ..."
echo "   $0 -t7043 -m140 -s111   the VPD of the selected node"
echo ""
exit 1;

exit 1
